@@ -25,11 +25,11 @@ cleandir () {
 exectests() {
   cleandir
   # compile model:
-  $CURRYBIN/erd2cdbi Uni_ERD.term `pwd`/Uni.db  
+  $CURRYBIN/curry erd2cdbi Uni_ERD.term `pwd`/Uni.db  
   # fill database:
   $CURRYBIN/curry :l CreateData :eval createTestData :q
   # run query tests:
-  $CURRYBIN/currycheck SelectExamples
+  $CURRYBIN/curry check SelectExamples
 }
 
 LOGFILE=xxx$$
